@@ -12,4 +12,5 @@ class Bootstrap(ComponentResource):
             resource.self = self
 
         # Create bootstrap resource group
-        bootstrap_rg = resource_group.resource_group('bootstrap', props)
+        # bootstrap_rg = resource_group.resource_group('bootstrap', props)
+        shared_res_grp = resource_group("Novari-Shared", props, opts.novari_provider, opts.novari_provider)
